obelisk.sync.consumer.Consumer
==============================

.. currentmodule:: obelisk.sync.consumer

.. autoclass:: Consumer
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Consumer.__init__
      ~Consumer.query
      ~Consumer.query_time_chunked
      ~Consumer.single_chunk
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Consumer.loop
      ~Consumer.async_consumer
   
   